@@ -26,7 +26,6 @@ from embedops_cli.api.rest import ApiException
 from embedops_cli.api.api_client import ApiClient
 from embedops_cli.eo_types import (
     DockerRegistryException,
-    DockerNotRunningException,
     LoginFailureException,
     UnauthorizedUserException,
     UnknownDockerException,
@@ -267,19 +266,6 @@ def get_user_client():
 def docker_cli_login(aws_access_key_id, aws_secret_access_key):
     """Login using Docker CLI. Returns the return code of the subprocess"""
 
-    try:
-        subprocess.check_output(
-            ("powershell " if platform.system() == "Windows" else "") + "docker info",
-            shell=True,
-            stderr=subprocess.DEVNULL,
-        )
-    except subprocess.CalledProcessError as err:
-        _logger.error(err.returncode)
-        if "Is the docker daemon running?" in str(err.stdout):
-            raise DockerNotRunningException from err
-
-        return err.returncode
-
     sts_client = boto3.client(
         "sts",
         aws_access_key_id=aws_access_key_id,
