@@ -278,7 +278,8 @@ def show(ctx: click.Context, verbose):
 
     if not verbose:
         try:
-            job_name_list = "\n".join(_get_job_name_list(filename))
+            job_list = _get_job_name_list(filename)
+            job_name_list = "\n".join([i for i in job_list if not i == "release"])
         except (UnsupportedYamlTypeException, BadYamlFileException) as exc:
             _echo_error_and_fix(exc)
             ctx.exit(2)
