@@ -10,11 +10,13 @@ from enum import Enum
 GH_CI_CONFIG_FILE_PATH = ".github/workflows"
 BB_CI_CONFIG_FILENAME = "bitbucket-pipelines.yml"
 GL_CI_CONFIG_FILENAME = ".gitlab-ci.yml"
+AD_CI_CONFIG_FILENAME = "azure-pipelines.yml"
 EO_CI_CONFIG_FILENAME = ".embedops-ci.yml"
 SUPPORTED_CI_FILENAMES = [
     BB_CI_CONFIG_FILENAME,
     GL_CI_CONFIG_FILENAME,
     EO_CI_CONFIG_FILENAME,
+    AD_CI_CONFIG_FILENAME,
 ]
 
 
