@@ -80,7 +80,7 @@ class TestEntrypoint:
         self.logger_mock.error.has_calls(call("ERROR: No commit id envvar found"))
         self.ci_run_caller.assert_not_called()
 
-    def test_no_branch_name(self, monkeypatch):
+    def test_no_branch_name_or_tag(self, monkeypatch):
         monkeypatch.delenv("BITBUCKET_BRANCH")
         ci_run = CIRun()
         with pytest.raises(SystemExit) as pytest_wrapped_e:
@@ -89,7 +89,7 @@ class TestEntrypoint:
         assert pytest_wrapped_e.value.code == 1
 
         self.logger_mock.error.assert_has_calls(
-            [call("ERROR: No branch name envvar found")]
+            [call("ERROR: No branch or tag name envvar found")]
         )
         self.ci_run_caller.assert_not_called()
 
@@ -133,7 +133,7 @@ class TestEntrypoint:
 
         expected_calls = [
             call("ERROR: No analysis type envvar found"),
-            call("ERROR: No branch name envvar found"),
+            call("ERROR: No branch or tag name envvar found"),
             call("ERROR: No commit id envvar found"),
         ]
 
@@ -162,7 +162,26 @@ class TestEntrypoint:
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 0
 
-        self.ci_run_caller.assert_called_with("memusage", "abcd1234", "main", None, None)
+        self.ci_run_caller.assert_called_with(
+            "memusage", "abcd1234", "main", None, None
+        )
+        self.logger_mock.info.assert_called_with(expected_id)
+
+    def test_successful_call_with_tag(self, monkeypatch):
+        monkeypatch.delenv("BITBUCKET_BRANCH")
+        monkeypatch.setenv("BITBUCKET_TAG", "production-0.0.1")
+        expected_id = "yabbazabba"
+        new_ci_run = MagicMock()
+        new_ci_run.id = expected_id
+        self.ci_run_caller.return_value = new_ci_run
+        with pytest.raises(SystemExit) as pytest_wrapped_e:
+            create_entry()
+        assert pytest_wrapped_e.type == SystemExit
+        assert pytest_wrapped_e.value.code == 0
+
+        self.ci_run_caller.assert_called_with(
+            "memusage", "abcd1234", "production-0.0.1", None, None
+        )
         self.logger_mock.info.assert_called_with(expected_id)
 
     def test_successful_call_with_job_name_and_pipeline_id(self, monkeypatch):
